@@ -48,10 +48,14 @@ def basic_auth(func):
     wrapper._pysi_urlname = _get_urlname(func)
     return wrapper
 
+def csrf_exempt(func):
+    func._pysi_csrf_exempt = True
+    return func
+
 def _get_urlname(func):
     if not getattr(func, '_pysi_urlname', None):
         mod_name = func.func_globals['__name__']
         app_name = mod_name[:-6] if mod_name.endswith('.views') else None
         urlname = '%s.%s' % (app_name, func.__name__) if app_name else func.__name__
         setattr(func, '_pysi_urlname', urlname)
-    return func._pysi_urlname
\ No newline at end of file
+    return func._pysi_urlname
