@@ -20,18 +20,17 @@ cfg.set_defaults(
     CSRF_TOKEN_POST_NAME = 'csrf',
     CSRF_TOKEN_TEMPLATE_NAME = 'csrf',
     CSRF_TOKEN_TEMPLATE_INPUT_NAME = 'csrf_token',
-    CSRF_EXEMPT_PREFIXES = (),
 )
 
 
 class CSRF(object):
-    def process_request(self, rq):
+    def process_view(self, rq, func, kwargs):
         token = rq.COOKIES.get(cfg.CSRF_TOKEN_COOKIE_NAME)
         if token:
             token = token.value
         if rq.method == 'POST':
-            if not rq.path.startswith(cfg.CSRF_EXEMPT_PREFIXES):
-                if token != rq.POST.get(cfg.CSRF_TOKEN_POST_NAME):
+            if not getattr(func, '_pysi_csrf_exempt', None):
+                if not token or token != rq.POST.get(cfg.CSRF_TOKEN_POST_NAME):
                     res = get_error_page(rq, 403)
                     if token is not None:
                         res.delete_cookie(cfg.CSRF_TOKEN_COOKIE_NAME)
